Modules
Functions
- Call this function once at program start so that
i3status_extcan pass-through the header fromstdinwhich comes initially from i3status. - dummiy version of
begin() - Call this function once at program start so that
i3status_extcan pass-through the header from given String (used for tests). - Insert new an item into i3status’s json string at given position. Call this within a loop continuously to add your custom item into the json data from i3status.